.c-hint[role=tooltip]{position:absolute;padding:var(--spacing-tiny) 0;color:var(--color-default);font-size:var(--text-font-size-medium);transform:scale(.8);transform-origin:top left;opacity:0;pointer-events:none}.c-field:focus~.c-hint,.c-hint[role=tooltip].c-hint--static,.c-label__field:focus~.c-hint{transform:scale(.9);opacity:1}