.c-list[role=list],ol.c-list,ul.c-list{display:block;margin:0;padding:0 0 0 var(--spacing-medium);list-style-position:outside}.c-list[role=list] .c-list[role=list],.c-list[role=list] ol.c-list,.c-list[role=list] ul.c-list,ol.c-list .c-list[role=list],ol.c-list ol.c-list,ol.c-list ul.c-list,ul.c-list .c-list[role=list],ul.c-list ol.c-list,ul.c-list ul.c-list{padding:0 0 0 var(--spacing-medium)}.c-list[role=list] .c-list__item,ol.c-list .c-list__item,ul.c-list .c-list__item{padding:0}.c-list[role=list] .c-list__item--unstyled,ol.c-list .c-list__item--unstyled,ul.c-list .c-list__item--unstyled{list-style:none}.c-list[role=list].c-list--unstyled,ol.c-list.c-list--unstyled,ul.c-list.c-list--unstyled{padding:0;list-style:none}.c-list[role=list].c-list--ordered,ol.c-list.c-list--ordered,ul.c-list.c-list--ordered{padding:0;list-style:none;counter-reset:ordered}.c-list[role=list].c-list--ordered .c-list__item:before,ol.c-list.c-list--ordered .c-list__item:before,ul.c-list.c-list--ordered .c-list__item:before{padding:0 var(--spacing-small) 0 0;content:counters(ordered,".") " ";counter-increment:ordered}.c-list[role=list].c-list--inline,.c-list[role=list].c-list--inline .c-list--inline,ol.c-list.c-list--inline,ol.c-list.c-list--inline .c-list--inline,ul.c-list.c-list--inline,ul.c-list.c-list--inline .c-list--inline{padding:0}.c-list[role=list].c-list--inline .c-list__item,ol.c-list.c-list--inline .c-list__item,ul.c-list.c-list--inline .c-list__item{display:inline-block;width:auto;padding-right:var(--spacing-medium)}.c-list[role=list].c-list--inline:not(.c-list--unstyled) .c-list__item:before,ol.c-list.c-list--inline:not(.c-list--unstyled) .c-list__item:before,ul.c-list.c-list--inline:not(.c-list--unstyled) .c-list__item:before{padding:0 var(--spacing-small) 0 0;content:"\2022"}