.c-file-upload{position:relative;display:inline-block;overflow:hidden}.c-file-upload--drop{display:block;padding:var(--spacing-medium);line-height:10;text-align:center;background-color:var(--color-background);border:3px dashed var(--color-dark);border-radius:var(--border-radius)}.c-file-upload input[type=file]{position:absolute;top:0;left:0;width:100%;height:100%;opacity:0}