.u-centered{text-align:center}.u-justified{text-align:justify}.u-left{text-align:left}.u-right{text-align:right}.u-center-block{position:relative}.u-absolute-center,.u-center-block__content{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}.u-center-block__content--vertical{left:auto;transform:translateY(-50%)}.u-center-block__content--horizontal{top:auto;transform:translateX(-50%)}