.c-input-group{display:flex}.c-input-group .c-button{border-radius:0}.c-input-group .c-button:not(:first-child){border-left-width:0}.c-input-group .c-button:first-child{border-top-left-radius:var(--border-radius);border-bottom-left-radius:var(--border-radius)}.c-input-group .c-button:last-child{border-top-right-radius:var(--border-radius);border-bottom-right-radius:var(--border-radius)}.c-input-group .o-field{flex:1}.c-input-group .o-field .c-field{border-radius:0}.c-input-group .o-field:not(:first-child) .c-field{border-left-width:0}.c-input-group .o-field:first-child .c-field{border-top-left-radius:var(--border-radius);border-bottom-left-radius:var(--border-radius)}.c-input-group .o-field:last-child .c-field{border-top-right-radius:var(--border-radius);border-bottom-right-radius:var(--border-radius)}.c-input-group .o-field--fixed{flex:0 1 auto}.c-input-group--label .c-button,.c-input-group--label .o-field{margin:var(--spacing-small) 0 0 0}.c-input-group--rounded .c-button:first-child{border-top-left-radius:var(--border-radius-rounded);border-bottom-left-radius:var(--border-radius-rounded)}.c-input-group--rounded .c-button:last-child{border-top-right-radius:var(--border-radius-rounded);border-bottom-right-radius:var(--border-radius-rounded)}.c-input-group--rounded .o-field:first-child .c-field{border-top-left-radius:var(--border-radius-rounded);border-bottom-left-radius:var(--border-radius-rounded)}.c-input-group--rounded .o-field:last-child .c-field{border-top-right-radius:var(--border-radius-rounded);border-bottom-right-radius:var(--border-radius-rounded)}.c-input-group--rounded-left .c-button:first-child,.c-input-group--rounded-left .o-field:first-child .c-field{border-top-left-radius:var(--border-radius-rounded);border-bottom-left-radius:var(--border-radius-rounded)}.c-input-group--rounded-right .c-button:last-child,.c-input-group--rounded-right .o-field:last-child .c-field{border-top-right-radius:var(--border-radius-rounded);border-bottom-right-radius:var(--border-radius-rounded)}.c-input-group--stacked{display:flex;flex-wrap:wrap}.c-input-group--stacked .c-button,.c-input-group--stacked .o-field{flex:0 0 100%;max-width:100%;margin-left:0}.c-input-group--stacked .c-button:not(:first-child){border-top:0;border-left-width:var(--border-width)}.c-input-group--stacked .c-button:not(:first-child):not(:last-child){border-radius:0}.c-input-group--stacked .c-button:first-child{border-radius:var(--border-radius) var(--border-radius) 0 0}.c-input-group--stacked .c-button:last-child{border-radius:0 0 var(--border-radius) var(--border-radius)}.c-input-group--stacked .o-field:not(:first-child) .c-field{border-top:0;border-left-width:var(--border-width)}.c-input-group--stacked .o-field:not(:first-child):not(:last-child) .c-field{border-left-width:var(--border-width);border-radius:0}.c-input-group--stacked .o-field:first-child .c-field{border-radius:var(--border-radius) var(--border-radius) 0 0}.c-input-group--stacked .o-field:last-child .c-field{border-radius:0 0 var(--border-radius) var(--border-radius)}