.c-overlay[aria-hidden]{position:fixed;top:0;right:0;bottom:0;left:0;z-index:var(--overlay-z-index);display:block;width:100%;height:100%;background-color:rgba(0,0,0,.4);visibility:hidden;opacity:0}.c-overlay[aria-hidden].c-overlay--visible{visibility:visible;opacity:1}.c-overlay[aria-hidden].c-overlay--transparent{background-color:transparent}