.c-range[type=range]{--range-track-color:var(--color-default);width:100%;padding:var(--spacing-small) 0;outline:0;-webkit-appearance:none}.c-range[type=range].c-range--brand{--range-track-color:var(--color-brand)}.c-range[type=range].c-range--info{--range-track-color:var(--color-info)}.c-range[type=range].c-range--warning{--range-track-color:var(--color-warning)}.c-range[type=range].c-range--success{--range-track-color:var(--color-success)}.c-range[type=range].c-range--error{--range-track-color:var(--color-error)}.c-range[type=range]:not(:disabled)::-webkit-slider-runnable-track{background-color:var(--range-track-color)}.c-range[type=range]:not(:disabled)::-moz-range-track{background-color:var(--range-track-color)}.c-range[type=range]:not(:disabled)::-ms-track{background-color:var(--range-track-color)}.c-range[type=range]:not(:disabled):active::-webkit-slider-thumb{transform:scale(1.4)}.c-range[type=range]:not(:disabled):active::-moz-range-thumb{transform:scale(1.4)}.c-range[type=range]:not(:disabled):active::-ms-thumb{transform:scale(1.4)}.c-range[type=range]:focus::-webkit-slider-thumb{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-range[type=range]:focus::-moz-range-thumb{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-range[type=range]:focus::-ms-thumb{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-range[type=range]:disabled::-webkit-slider-runnable-track,.c-range[type=range]:disabled::-webkit-slider-thumb{background-color:var(--color-disabled-background);cursor:not-allowed}.c-range[type=range]:disabled::-moz-range-thumb,.c-range[type=range]:disabled::-moz-range-track{background-color:var(--color-disabled-background);cursor:not-allowed}.c-range[type=range]:disabled::-ms-thumb,.c-range[type=range]:disabled::-ms-track{background-color:var(--color-disabled-background);cursor:not-allowed}.c-range::-webkit-slider-runnable-track{width:100%;height:10px;border:0;border-radius:var(--border-radius-rounded);box-shadow:none}.c-range::-webkit-slider-thumb{width:20px;height:20px;margin:-5px 0 0;background-color:#fff;border:0;border-radius:var(--border-radius-rounded);box-shadow:0 1px 4px -1px #000;-webkit-appearance:none}.c-range::-moz-range-track{width:100%;height:10px;border:0;border-radius:var(--border-radius-rounded);box-shadow:none}.c-range::-moz-range-thumb{width:20px;height:20px;margin:-5px 0 0;background-color:#fff;border:0;border-radius:var(--border-radius-rounded);box-shadow:0 1px 4px -1px #000}.c-range::-ms-track{width:100%;height:10px;border:0;border-radius:var(--border-radius-rounded);box-shadow:none;color:transparent;background-color:transparent;border-color:transparent}.c-range::-ms-fill-lower,.c-range::-ms-fill-upper{background-color:var(--color-default);border:0;border-radius:var(--border-radius-rounded);box-shadow:none}.c-range::-ms-thumb{width:20px;height:20px;margin:-5px 0 0;background-color:#fff;border:0;border-radius:var(--border-radius-rounded);box-shadow:0 1px 4px -1px #000}