.c-table{display:flex;flex-wrap:wrap;width:100%;margin:0;padding:0;border:0;border-collapse:collapse;border-spacing:0}.c-table__caption{display:flex;flex:0 0 100%;margin-left:0;max-width:100%;padding:var(--spacing-small) 0;color:var(--color-default);font-size:var(--text-font-size-small);text-align:left}.c-table__body,.c-table__head,.c-table__row{display:flex;flex:0 0 100%;flex-wrap:wrap;max-width:100%}.c-table--striped :not(.c-table__row--heading).c-table__row:nth-of-type(odd){color:initial;background-color:var(--color-background)}.c-table__cell{display:flex;flex:1;padding:var(--spacing-small);overflow:auto;text-align:left}.c-table__row--heading .c-table__cell{display:flex;flex:1;color:inherit;font-weight:var(--text-font-weight-heavy);font-size:var(--text-font-size-medium);background-color:var(--color-background)}.c-table--striped .c-table__row--heading .c-table__cell{color:initial;background-color:#fff;border-bottom:var(--border-width) var(--border-style) var(--border-color)}.c-table--clickable :not(.c-table__row--heading).c-table__row:hover .c-table__cell,.c-table__row--clickable:hover .c-table__cell{color:var(--link-color);background-color:initial}.c-table__row--disabled{color:var(--color-disabled);background-color:initial;cursor:default}.c-table--clickable :not(.c-table__row--heading).c-table__row--disabled:hover .c-table__cell,.c-table__row--disabled:hover .c-table__cell{color:var(--color-disabled);background-color:initial;cursor:not-allowed}.c-table--condensed{font-size:var(--text-font-size-small)}.c-table--condensed .c-table__cell{padding:var(--spacing-xsmall)}