import t from"/static/logging/index.js";import"/static/pwa/index.js";import{sort as s}from"/static/blaze/index.js";import e from"/static/security/sanitizer.js";import o from"/static/quotquot/element.js";import i from"/static/quotquot/plugins/events.js";import r from"/static/quotquot/plugins/i18n.js";import a from"/static/quotquot/plugins/style.js";import n from"/static/quotquot/plugins/class.js";var m="store-homepage",p={blaze:["utilities.typography"]};t.getLogger("ruteni.app.store.element.homepage").setLevel("DEBUG");const c=document.createElement("template");c.innerHTML=e.sanitize('<workbox-window url="sw.js"></workbox-window><div class="u-text"><h1>homepage</h1></div>');const l=p.blaze;s(l);window.customElements.define(m,class extends o{constructor(){const t={styles:l.map((t=>`/static/blaze/css/${t}.css`)),events:{}};super({template:c,state:t,Plugins:[i,r,a,n]})}});
