.o-media{display:flex}.o-media .c-heading{padding:0}.o-media__body,.o-media__image{flex:1;padding-right:.001em;padding-left:.001em}.o-media__body--top,.o-media__image--top{align-self:flex-start}.o-media__body--center,.o-media__image--center{align-self:center}.o-media__body--bottom,.o-media__image--bottom{align-self:flex-end}.o-media__image{flex:0 1 auto;width:3em}.o-media__body{margin-left:var(--spacing-small)}