.c-back-to-top{position:fixed;right:2em;bottom:2em;z-index:var(--z-over-page)}.c-back-to-top.c-back-to-top--left{right:auto;left:2em}.c-back-to-top.c-back-to-top--center{right:auto;left:50%;transform:translateX(-50%)}