.u-text{color:var(--color-text);font-weight:var(--text-font-weight);font-family:var(--text-font-family);line-height:var(--text-line-height);direction:ltr;text-align:left}.u-text--rtl{direction:rtl;text-align:right}.u-text--mono{font-family:var(--text-font-family-mono)!important}.u-text--highlight{display:inline;margin:0 calc(var(--spacing-tiny)*-1);padding:var(--spacing-xsmall) var(--spacing-xsmall) var(--spacing-tiny);color:var(--color-text)!important;font-weight:var(--text-font-weight)!important;background-color:var(--color-highlight)!important}.u-text--quiet{color:var(--color-quiet)!important}.u-text--loud{font-weight:var(--text-font-weight-heavy)!important}.u-text--normal{font-weight:400}.u-text--italic{font-style:italic}.u-text--help[title]{text-decoration:none!important;border-bottom:1px dashed var(--color-default)!important;cursor:help!important}.u-pre{margin:0}.u-code{display:inline;margin:0 calc(var(--spacing-tiny)*-1);padding:var(--spacing-xsmall) var(--spacing-xsmall) var(--spacing-tiny);color:var(--color-text)!important;font-weight:var(--text-font-weight)!important;font-family:var(--text-font-family-mono)!important;background-color:var(--color-dark)!important}.u-code--multiline{display:block;padding:var(--spacing-small) var(--spacing-medium);overflow-x:auto!important;white-space:pre!important;word-wrap:normal!important}.u-code--multiline,.u-kbd{border-radius:var(--border-radius)}.u-kbd{display:inline;margin:0 calc(var(--spacing-tiny)*-1);padding:var(--spacing-xsmall) var(--spacing-xsmall) var(--spacing-tiny);color:var(--color-text)!important;font-weight:var(--text-font-weight)!important;font-family:var(--text-font-family-mono)!important;background-color:var(--color-dark)!important;border-bottom:2px solid var(--color-default)}.u-blockquote{--quotation-border-color:var(--color-default);display:block;margin:0;padding:var(--spacing-medium) var(--spacing-large);font-family:var(--text-font-family-serif)!important;border-left:5px solid var(--quotation-border-color)!important}.u-blockquote--brand{--quotation-border-color:var(--color-brand)}.u-blockquote--info{--quotation-border-color:var(--color-info)}.u-blockquote--warning{--quotation-border-color:var(--color-warning)}.u-blockquote--success{--quotation-border-color:var(--color-success)}.u-blockquote--error{--quotation-border-color:var(--color-error)}.u-blockquote__body{font-size:var(--text-font-size-large)}.u-blockquote__body,.u-blockquote__footer{display:block;margin:0;padding:var(--spacing-small) 0}.u-blockquote__footer{color:var(--color-quiet)!important;font-style:italic!important}.u-paragraph{display:block;margin:0;padding:var(--spacing-small) 0}.u-gradient-text{display:inline-block;color:transparent;-webkit-background-clip:text;background-clip:text;background-image:linear-gradient(135deg,#00f,purple)}.u-gradient-text--info{background-image:linear-gradient(135deg,#87ceeb,#00f)}.u-gradient-text--warning{background-image:linear-gradient(135deg,orange,red)}.u-gradient-text--success{background-image:linear-gradient(135deg,green,#00f)}.u-gradient-text--error{background-image:linear-gradient(135deg,red,purple)}