.c-breadcrumbs{display:block;margin:0;padding:0;list-style:none}.c-breadcrumbs__crumb{display:inline-block;width:auto;padding:0}.c-breadcrumbs__crumb:not([aria-current]) :after{padding:0 var(--spacing-small);color:var(--color-default);content:"/"}.c-breadcrumbs__crumb[aria-current]{font-weight:var(--text-font-weight-heavy)}