.c-pagination[role=navigation],nav.c-pagination{display:flex;width:100%;padding:var(--spacing-medium);font-size:var(--text-font-size-medium);text-align:center}.c-pagination__pages{display:flex;flex:1 0 auto;justify-content:center}.c-pagination__pages .c-pagination__control{margin:0 .2em}.c-pagination__control{--button-color:var(--color-brand);color:var(--button-color);background-color:var(--button-background-color);border:1px solid transparent;display:inline-block;max-width:100%;margin:0;padding:var(--spacing-small);overflow:hidden;font-size:1em;font-family:inherit;line-height:normal;white-space:nowrap;text-align:center;text-decoration:none;text-overflow:ellipsis;vertical-align:middle;border-radius:var(--border-radius);outline:0;-webkit-appearance:none;appearance:none;user-select:none;--button-background-color:transparent;border:1px solid var(--button-color);flex:0 0 auto;min-width:2.4em;border-radius:var(--border-radius-rounded)}.c-pagination__control.c-button--active,.c-pagination__control:not(:disabled):not([disabled]):not(:active):hover{filter:brightness(.95)}.c-pagination__control:not(:disabled):not([disabled]):active{filter:brightness(.9)}.c-pagination__control:disabled,.c-pagination__control[disabled]{cursor:not-allowed;opacity:var(--disabled-opacity)}.c-pagination__control.c-button--active,.c-pagination__control:not(:disabled):not([disabled]):not(:active):hover{color:#fff;background-color:var(--button-color);border-color:1px solid transparent}.c-pagination__control:not(:disabled):not([disabled]):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-pagination__control:not(:disabled):not([disabled]):active,.c-pagination__control:not(:disabled):not([disabled])[aria-current]{color:#fff;background-color:var(--button-color);border-color:1px solid transparent}