.c-card{display:block;width:100%;padding:0;overflow:hidden;background-color:var(--color-background);border-radius:var(--border-radius)}.c-card>.o-image:not(:first-child){padding:var(--spacing-medium) 0 0}.c-card+.c-card{margin:var(--spacing-small) 0 0 0}.c-card__header{padding:var(--spacing-medium) var(--spacing-medium) 0}.c-card__header .c-heading{padding:0}.c-card__body,.c-card__footer{padding:var(--spacing-medium)}.c-card__footer--block{padding:var(--spacing-small) 0 0}.c-card__footer--block .c-input-group .c-button{border-bottom:0}.c-card__footer--block .c-input-group .c-button:first-child{border-left:0;border-top-left-radius:0;border-bottom-left-radius:0}.c-card__footer--block .c-input-group .c-button:last-child{border-right:0;border-top-right-radius:0;border-bottom-right-radius:0}.c-card__item{--card-item-color:var(--color-text);--card-item-background-color:transparent;margin:0;padding:var(--spacing-small);color:var(--card-item-color);background-color:var(--card-item-background-color)}.c-card__item:disabled,.c-card__item[disabled]{cursor:not-allowed;opacity:var(--disabled-opacity)}.c-card__item--divider[role=separator]{--card-item-color:#000;--card-item-background-color:var(--color-dark);font-weight:var(--text-font-weight-heavy)}.c-card__item--brand{--card-item-color:#fff;--card-item-background-color:var(--color-brand)}.c-card__item--info{--card-item-color:#fff;--card-item-background-color:var(--color-info)}.c-card__item--warning{--card-item-color:#000;--card-item-background-color:var(--color-warning)}.c-card__item--success{--card-item-color:#fff;--card-item-background-color:var(--color-success)}.c-card__item--error{--card-item-color:#fff;--card-item-background-color:var(--color-error)}.c-card__item+.c-card__footer--block{padding:0}.c-card--grouped .c-card__item:not(:last-child){border-bottom:0}.c-card__divider[role=separator]{height:var(--border-width);overflow:hidden;background-color:var(--border-color)}.c-card__control{--button-color:var(--color-text);--button-background-color:var(--color-dark);display:inline-block;max-width:100%;overflow:hidden;font-size:1em;font-family:inherit;line-height:normal;white-space:nowrap;text-align:center;text-decoration:none;text-overflow:ellipsis;vertical-align:middle;border-radius:var(--border-radius);outline:0;-webkit-appearance:none;appearance:none;user-select:none;color:var(--button-color);background-color:var(--button-background-color);position:relative;display:block;width:100%;margin:0;padding:var(--spacing-small);text-align:inherit;text-decoration:inherit;border:0;border-radius:0}.c-card__control:disabled,.c-card__control[disabled]{cursor:not-allowed;opacity:var(--disabled-opacity)}.c-card__control.c-button--active,.c-card__control:not(:disabled):not([disabled]):not(:active):hover{filter:brightness(.95)}.c-card__control:not(:disabled):not([disabled]):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-card__control:not(:disabled):not([disabled]):active{filter:brightness(.9)}.c-card__control[aria-expanded=true]{font-weight:var(--text-font-weight-heavy);filter:brightness(.95)}.c-card__control.c-card__control--active{filter:brightness(.95)}.c-card--menu[role=menu]{position:absolute;width:100%;max-height:300px;margin-top:.5em;overflow-x:hidden;overflow-y:auto;text-overflow:ellipsis;border:1px solid var(--color-dark);border-radius:0 0 var(--border-radius) var(--border-radius)}.c-card--menu[role=menu] .c-card__control[role=menuitem]{--button-background-color:var(--color-light)}.c-card--accordion .c-card__control[aria-expanded]:after{position:absolute;top:.5em;right:.5em;width:1em;height:1em;background-image:url(../icon.png);background-repeat:no-repeat;background-position:50%;content:""}.c-card--accordion .c-card__control[aria-expanded][aria-expanded=true]:after{transform:rotate(180deg)}.c-card__item--pane{margin:0;padding:var(--spacing-small)}.c-card__control[aria-expanded=false]+.c-card__item--pane{position:absolute;width:1px;height:1px;overflow:hidden;clip-path:inset(50%)}