.c-tabs[role=tablist]{display:block}.c-tabs__headings{display:flex;text-align:center}.c-tabs__nav{overflow:hidden}.c-tabs__nav .c-tabs__headings{margin-bottom:-1em;padding-bottom:1em;overflow-x:auto;overflow-y:hidden}.c-tab-heading[role=tab]{--tab-heading-border-color:var(--color-default);width:auto;padding:0;overflow:visible;color:inherit;font:inherit;line-height:normal;text-align:inherit;text-decoration:inherit;vertical-align:inherit;background:inherit;border:0;border-radius:0;outline:0;-webkit-appearance:none;appearance:none;display:block;flex:1;margin:0;padding:var(--spacing-medium);white-space:nowrap;border-bottom:var(--spacing-xsmall) solid var(--color-background);border-radius:var(--border-radius) var(--border-radius) 0 0}.c-tab-heading[role=tab]:disabled,.c-tab-heading[role=tab][disabled]{cursor:not-allowed;opacity:var(--disabled-opacity)}.c-tab-heading[role=tab]:not(:disabled):not([disabled]):active{background-color:transparent}.c-tab-heading[role=tab]:not(:disabled):not([disabled]):not(:active):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-tab-heading[role=tab]:not(:disabled):not([disabled]):not(:active):hover{background-color:transparent}.c-tab-heading[role=tab].c-tab-heading--active,.c-tab-heading[role=tab]:not(:disabled):not(.c-tab-heading--active):hover{border-bottom-color:var(--tab-heading-border-color)}.c-tab-heading[role=tab].c-tab-heading--active{background-color:var(--color-background)}.c-tab-heading[role=tab].c-tab-heading--brand{--tab-heading-border-color:var(--color-brand)}.c-tab-heading[role=tab].c-tab-heading--info{--tab-heading-border-color:var(--color-info)}.c-tab-heading[role=tab].c-tab-heading--warning{--tab-heading-border-color:var(--color-warning)}.c-tab-heading[role=tab].c-tab-heading--success{--tab-heading-border-color:var(--color-success)}.c-tab-heading[role=tab].c-tab-heading--error{--tab-heading-border-color:var(--color-error)}.c-tabs__tab[role=tabpanel]{padding:var(--spacing-medium)}