<!doctype html>
<html lang="{{lang}}">
  <head>
    <meta charset="utf-8">
    <title>{{title}}</title>
    <link rel="manifest" href="{{manifest}}">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="Description" content="{{description}}">
    <meta name="theme-color" content="{{theme_color}}">
    <link rel="apple-touch-icon" href="{{apple_touch_icon}}">
    <script src="/static/store/index.js" type="module" defer></script>
  </head>
  <body>
  </body>
</html>
