import e from"/static/logging/index.js";import t from"/static/quotquot/element.js";import n from"/static/quotquot/plugins/i18n.js";import"/static/quotquot/router.js";import"/static/store/elements/homepage/index.js";import"/static/store/elements/settings/index.js";const o=e.getLogger("ruteni.app.store");o.setLevel("DEBUG");const s=document.createElement("h1");s.dataset.i18n="unknown-page";const r=document.createElement("template");r.innerHTML=s.outerHTML;window.customElements.define("unknown-page",class extends t{constructor(){super({template:r,Plugins:[n]})}});const i=document.createElement("unknown-page"),a=document.createElement("default-route");a.appendChild(i);const p=document.createElement("hash-router"),u=new Map([["store-homepage",{type:"static-route",path:"",keep:!0}],["store-settings",{type:"static-route",path:"#/settings"}]]);for(const[e,t]of u){const n=document.createElement(t.type);n.setAttribute("element",e),n.setAttribute("path",t.path),t.keep&&n.setAttribute("keep",""),p.appendChild(n)}p.appendChild(a),document.body.appendChild(p),o.debug("configured");
