@charset "UTF-8";.c-tree[role=tree]{display:block;margin:0;padding:0}.c-tree[role=tree] .c-tree[role=tree]{padding:0 0 0 var(--spacing-medium)}.c-tree__item[role=treeitem]{width:auto;margin:0;overflow:visible;color:inherit;font:inherit;line-height:normal;text-align:inherit;text-decoration:inherit;vertical-align:inherit;background:inherit;border:0;border-radius:0;outline:0;-webkit-appearance:none;appearance:none;display:block;margin:var(--spacing-small);padding:0;white-space:nowrap}.c-tree__item[role=treeitem]:disabled,.c-tree__item[role=treeitem][disabled]{cursor:not-allowed;opacity:var(--disabled-opacity)}.c-tree__item[role=treeitem]:not(:disabled):not([disabled]):active{background-color:transparent}.c-tree__item[role=treeitem]:not(:disabled):not([disabled]):not(:active):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-tree__item[role=treeitem]:not(:disabled):not([disabled]):not(:active):hover{background-color:transparent}.c-tree__item[role=treeitem]:before{display:inline-block;padding:0 var(--spacing-small) 0 0;color:var(--color-default);transform-origin:30% 50%;content:"–"}.c-tree__item[role=treeitem]+.c-tree[role=tree]{display:none}.c-tree__item[aria-expanded]:before{content:"\276F"}.c-tree__item[aria-expanded=true]:before{transform:rotate(90deg);content:"\276F"}.c-tree__item[aria-expanded=true]+.c-tree[role=tree]{display:block}