import t from"/static/logging/index.js";import{sort as s}from"/static/blaze/index.js";import e from"/static/security/sanitizer.js";import i from"/static/quotquot/element.js";import o from"/static/quotquot/plugins/events.js";import n from"/static/quotquot/plugins/i18n.js";import r from"/static/quotquot/plugins/style.js";import a from"/static/quotquot/plugins/class.js";var m="store-settings",c={blaze:["utilities.typography"]};t.getLogger("ruteni.app.store.element.settings").setLevel("DEBUG");const l=document.createElement("template");l.innerHTML=e.sanitize('<div class="u-text"><h1>settings</h1></div>');const u=c.blaze;s(u);window.customElements.define(m,class extends i{constructor(){const t={styles:u.map((t=>`/static/blaze/css/${t}.css`)),events:{}};super({template:l,state:t,Plugins:[o,n,r,a]})}});
