.c-toggle{display:flex;align-items:center;width:auto;user-select:none}.c-toggle input:not(:checked)+.c-toggle__track{background-color:var(--color-dark)}.c-toggle input:not(:checked)+.c-toggle__track .c-toggle__handle{transform:translateZ(0)}.c-toggle input:disabled+.c-toggle__track,.c-toggle input:disabled+.c-toggle__track .c-toggle__handle{cursor:not-allowed;opacity:var(--disabled-opacity)}.c-toggle input:active+.c-toggle__track,.c-toggle input:focus+.c-toggle__track{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-toggle input:active+.c-toggle__track .c-toggle__handle,.c-toggle input:focus+.c-toggle__track .c-toggle__handle{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus),0 1px 3px 1px var(--color-default)}.c-toggle--brand .c-toggle__track{--toggle-track-color:var(--color-brand)}.c-toggle--info .c-toggle__track{--toggle-track-color:var(--color-info)}.c-toggle--warning .c-toggle__track{--toggle-track-color:var(--color-warning)}.c-toggle--success .c-toggle__track{--toggle-track-color:var(--color-success)}.c-toggle--error .c-toggle__track{--toggle-track-color:var(--color-error)}.c-toggle input{position:absolute;opacity:0}.c-toggle__track{--toggle-track-color:var(--color-default);flex:1;padding-right:var(--grid-gutter);padding-left:var(--grid-gutter);flex:0 1 auto;position:relative;height:.5em;margin:0 .5em;background-color:var(--toggle-track-color)}.c-toggle__handle,.c-toggle__track{width:1em;border-radius:var(--border-radius-rounded)}.c-toggle__handle{position:absolute;top:-.25em;left:0;height:1em;background-color:#fff;box-shadow:0 1px 3px 1px var(--color-default);transform:translateX(100%)}