.u-super{font-size:var(--text-font-size-super)}.u-xlarge{font-size:var(--text-font-size-xlarge)}.u-large{font-size:var(--text-font-size-large)}.u-medium{font-size:var(--text-font-size-medium)}.u-small{font-size:var(--text-font-size-small)}.u-xsmall{font-size:var(--text-font-size-xsmall)}