.c-link[role=link],a.c-link{color:var(--color-link);background-color:transparent;text-decoration:none;cursor:pointer}.c-link[role=link]:disabled,.c-link[role=link][disabled],a.c-link:disabled,a.c-link[disabled]{cursor:not-allowed;opacity:var(--disabled-opacity)}.c-link[role=link]:not(:disabled):visited,a.c-link:not(:disabled):visited{opacity:.9}.c-link[role=link]:not(:disabled):hover,a.c-link:not(:disabled):hover{background-color:transparent;opacity:.9}.c-link[role=link]:not(:disabled):active,a.c-link:not(:disabled):active{background-color:transparent;opacity:.8}.c-link[role=link]:hover,a.c-link:hover{text-decoration:underline}.c-link[role=link] .c-link--skip,a.c-link .c-link--skip{position:absolute;width:1px;height:1px;overflow:hidden;clip-path:inset(50%);top:0;left:0;z-index:var(--z-over-everything)}.c-link[role=link] .c-link--skip:active,.c-link[role=link] .c-link--skip:focus,a.c-link .c-link--skip:active,a.c-link .c-link--skip:focus{width:auto;height:auto;overflow:auto;clip-path:none}.c-link[role=link].c-link--brand,a.c-link.c-link--brand{--color-link:var(--color-brand)}.c-link[role=link].c-link--info,a.c-link.c-link--info{--color-link:var(--color-info)}.c-link[role=link].c-link--warning,a.c-link.c-link--warning{--color-link:var(--color-warning)}.c-link[role=link].c-link--success,a.c-link.c-link--success{--color-link:var(--color-success)}.c-link[role=link].c-link--error,a.c-link.c-link--error{--color-link:var(--color-error)}