input {
    -webkit-text-size-adjust: 100%;
    box-sizing: border-box;
    margin: 0;
    font-size: 100%;
    vertical-align: middle;
    transition: all .1s linear;
    font-family: Arial,sans-serif;
    color: #111;
    border: 1px solid #a6a6a6;
    border-top-color: #949494;
    border-radius: 3px;
    box-shadow: 0 1px 0 rgba(255,255,255,.5),0 1px 0 rgba(0,0,0,.07) inset;
    outline: 0;
    background-color: #fff;
    height: 31px;
    padding: 3px 7px;
    line-height: normal;
    width: 100%;
    margin-right: 0;
    animation-name: onAutoFillChanged;
}

label {
    -webkit-text-size-adjust: 100%;
    font-size: 13px;
    line-height: 19px;
    color: #111;
    font-family: Arial,sans-serif;
    box-sizing: border-box;
    padding-left: 2px;
    padding-bottom: 2px;
    font-weight: 700;
}

:host > div {
    -webkit-text-size-adjust: 100%;
    margin: auto;
    width: 350px;
    font-size: 13px;
    line-height: 19px;
    color: #111;
    font-family: Arial,sans-serif;
    box-sizing: border-box;
    border-radius: 4px;
    border: 1px #ddd solid;
    background-color: #fff;
    margin-bottom: 26px!important;
}

:host > div > div {
    -webkit-text-size-adjust: 100%;
    font-size: 13px;
    line-height: 19px;
    color: #111;
    font-family: Arial,sans-serif;
    box-sizing: border-box;
    border-radius: 4px;
    position: relative;
    padding: 14px 18px;
}

div[aria-live="assertive"][role="alert"] {
    display: none;
}

.issues {
    height: 1em;
    color: red;
}

.houdini {
    display: none;
}

.houdini.visible {
    display: block;
}

form > div {
    margin-bottom: 1em !important;
}

.password-info {
    margin-top: .5em !important;
}

input.verification-bode {
    width: 30%;
    margin: 0 auto;
}
