import t from"/static/logging/index.js";import e from"/static/security/sanitizer.js";import s from"/static/quotquot/element.js";import i from"/static/quotquot/plugins/events.js";import o from"/static/quotquot/plugins/i18n.js";import r from"/static/quotquot/plugins/style.js";import n from"/static/quotquot/plugins/class.js";t.getLogger("ruteni.plugin.registration.element.homepage").setLevel("DEBUG");const m=document.createElement("template");m.innerHTML=e.sanitize("<registration-form></registration-form>");window.customElements.define("registration-homepage",class extends s{constructor(){super({template:m,state:{issues:{},state:"editing",styles:["/static/registration/elements/homepage/index.css"],events:{}},Plugins:[i,o,r,n]})}});
