.o-modal[role=dialog]{position:fixed;top:50%;left:50%;z-index:var(--z-over-everything);display:block;width:75%;overflow:hidden;background-color:var(--color-background);border:0;border-radius:var(--border-radius);transform:translate(-50%,-50%);visibility:hidden;opacity:0}.o-modal[role=dialog]>.c-card{background-color:transparent;box-shadow:none}.o-modal[role=dialog]>.c-card .c-card__body{position:relative}.o-modal[role=dialog].o-modal--ghost{color:#fff;background-color:var(--color-transparent)}.o-modal[role=dialog].o-modal--ghost .c-heading{color:#fff}.o-modal[role=dialog].o-modal--full{top:1em;left:1em;width:calc(100% - 2em);height:calc(100% - 2em);transform:none}.o-modal[role=dialog].o-modal--full .c-card:first-child{box-shadow:none}.o-modal[role=dialog].o-modal--full .c-card__body{position:absolute;top:3.5em;bottom:4em;width:100%;overflow-x:hidden;overflow-y:auto;-webkit-overflow-scrolling:touch}.o-modal[role=dialog].o-modal--full .c-card__footer{position:absolute;bottom:0;width:100%}.o-modal[role=dialog].o-modal--visible{visibility:visible;opacity:1}.c-button--close{top:var(--spacing-small)}