.c-tooltip{position:relative;overflow:visible}.c-tooltip:after,.c-tooltip:before{z-index:var(--z-over-page);visibility:hidden}.c-tooltip:before{position:absolute;border:.6em solid transparent;content:""}.c-tooltip:after{position:absolute;padding:.25em .5em;color:#fff;line-height:1.45;white-space:nowrap;background-color:#000;border:1px solid #000;border-radius:var(--border-radius);visibility:hidden;content:attr(aria-label)}.c-tooltip:hover:after,.c-tooltip:hover:before{visibility:visible}.c-tooltip--top:before{top:0;left:50%;border-top-color:#000;transform:translate(-50%,-1em)}.c-tooltip--top:after{top:0;left:50%;transform:translate(-50%,-3em)}.c-tooltip--right:before{top:50%;left:100%;border-right-color:#000;transform:translateY(-50%)}.c-tooltip--right:after{top:50%;left:100%;transform:translate(1em,-50%)}.c-tooltip--bottom:before{bottom:0;left:50%;border-bottom-color:#000;transform:translate(-50%,1em)}.c-tooltip--bottom:after{bottom:0;left:50%;transform:translate(-50%,3em)}.c-tooltip--left:before{top:50%;right:100%;border-left-color:#000;transform:translateY(-50%)}.c-tooltip--left:after{top:50%;right:100%;transform:translate(-1em,-50%)}