aside.o-drawer{position:fixed;z-index:var(--z-over-everything);overflow-x:hidden;overflow-y:auto;color:inherit;background-color:var(--color-background);visibility:hidden;-webkit-overflow-scrolling:touch}aside.o-drawer .c-card{background-color:transparent;box-shadow:none}aside.o-drawer:not(.o-drawer--visible).u-high,aside.o-drawer:not(.o-drawer--visible).u-higher,aside.o-drawer:not(.o-drawer--visible).u-highest{box-shadow:none}aside.o-drawer.o-drawer--bottom,aside.o-drawer.o-drawer--top{left:0;width:80%;height:auto;margin-left:10%;transform:translate(0)}aside.o-drawer.o-drawer--bottom{top:100%;border-radius:var(--border-radius) var(--border-radius) 0 0}aside.o-drawer.o-drawer--bottom.o-drawer--visible{transform:translateY(-99%)}aside.o-drawer.o-drawer--top{bottom:100%;border-radius:0 0 var(--border-radius) var(--border-radius)}aside.o-drawer.o-drawer--top.o-drawer--visible{transform:translateY(99%)}aside.o-drawer.o-drawer--left,aside.o-drawer.o-drawer--right{top:0;width:260px;height:100%}aside.o-drawer.o-drawer--left .c-card__footer--block,aside.o-drawer.o-drawer--right .c-card__footer--block{position:absolute;bottom:0;width:100%}aside.o-drawer.o-drawer--left .c-card__footer--block .c-button,aside.o-drawer.o-drawer--right .c-card__footer--block .c-button{border-radius:0}aside.o-drawer.o-drawer--left{left:0;transform:translateX(-100%)}aside.o-drawer.o-drawer--left.o-drawer--visible{transform:translateX(-1%)}aside.o-drawer.o-drawer--right{left:100%;transform:translate(0)}aside.o-drawer.o-drawer--right.o-drawer--visible{transform:translateX(-99%)}aside.o-drawer.o-drawer--visible{visibility:visible}