.c-calendar{display:flex;flex-wrap:wrap;align-items:center;z-index:var(--z-over-control);max-width:400px;padding:var(--spacing-medium);text-align:center;background-color:var(--color-background)}.c-calendar,.c-calendar__control,.c-calendar__date{border:1px solid transparent;border-radius:var(--border-radius)}.c-calendar__control,.c-calendar__date{--button-color:var(--color-quiet);--button-background-color:transparent;color:var(--button-color);background-color:var(--button-background-color);display:inline;flex:0 0 12%;max-width:12%;margin:1.1%;padding:2.5% 0;font-size:var(--text-font-size-medium);outline:0;user-select:none}.c-calendar__control.c-button--active,.c-calendar__control:not(:disabled):not([disabled]):not(:active):hover,.c-calendar__date.c-button--active,.c-calendar__date:not(:disabled):not([disabled]):not(:active):hover{filter:brightness(.95)}.c-calendar__control:not(:disabled):not([disabled]):focus,.c-calendar__date:not(:disabled):not([disabled]):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-calendar__control:not(:disabled):not([disabled]):active,.c-calendar__date:not(:disabled):not([disabled]):active{filter:brightness(.9)}.c-calendar__control:hover,.c-calendar__date:hover{border-color:var(--border-color)}.c-calendar__control{--button-color:var(--color-default)}.c-calendar__header{flex:1;flex:0 0 71.5%;max-width:71.5%;padding:var(--spacing-small) 0}.c-calendar__day{flex:1;flex:0 0 12%;max-width:12%;margin:1.1%;padding:var(--spacing-small) 0;font-weight:var(--text-font-weight-heavy)}.c-calendar__date--in-month{--button-color:#000}.c-calendar__date[aria-current=date]{border-color:var(--border-color)}.c-calendar__date--selected[aria-selected=true],.c-calendar__date--selected[aria-selected=true]:hover{--button-color:#fff;color:var(--button-color);background-color:var(--button-background-color);border:1px solid transparent}.c-calendar__date--selected[aria-selected=true].c-button--active,.c-calendar__date--selected[aria-selected=true]:hover.c-button--active,.c-calendar__date--selected[aria-selected=true]:hover:not(:disabled):not([disabled]):not(:active):hover,.c-calendar__date--selected[aria-selected=true]:not(:disabled):not([disabled]):not(:active):hover{filter:brightness(.95)}.c-calendar__date--selected[aria-selected=true]:hover:not(:disabled):not([disabled]):focus,.c-calendar__date--selected[aria-selected=true]:not(:disabled):not([disabled]):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-calendar__date--selected[aria-selected=true]:hover:not(:disabled):not([disabled]):active,.c-calendar__date--selected[aria-selected=true]:not(:disabled):not([disabled]):active{filter:brightness(.9)}.c-calendar__footer{width:100%;padding-top:var(--spacing-large)}