.o-container{margin:auto}@media (min-width:20em){.o-container--xsmall\@xsmall{max-width:20em}.o-container--small\@xsmall{max-width:30em}.o-container--medium\@xsmall{max-width:48em}.o-container--large\@xsmall{max-width:64em}.o-container--xlarge\@xsmall{max-width:78em}.o-container--super\@xsmall{max-width:116em}}@media (min-width:30em){.o-container--xsmall\@small{max-width:20em}.o-container--small\@small{max-width:30em}.o-container--medium\@small{max-width:48em}.o-container--large\@small{max-width:64em}.o-container--xlarge\@small{max-width:78em}.o-container--super\@small{max-width:116em}}@media (min-width:48em){.o-container--xsmall\@medium{max-width:20em}.o-container--small\@medium{max-width:30em}.o-container--medium\@medium{max-width:48em}.o-container--large\@medium{max-width:64em}.o-container--xlarge\@medium{max-width:78em}.o-container--super\@medium{max-width:116em}}@media (min-width:64em){.o-container--xsmall\@large{max-width:20em}.o-container--small\@large{max-width:30em}.o-container--medium\@large{max-width:48em}.o-container--large\@large{max-width:64em}.o-container--xlarge\@large{max-width:78em}.o-container--super\@large{max-width:116em}}@media (min-width:78em){.o-container--xsmall\@xlarge{max-width:20em}.o-container--small\@xlarge{max-width:30em}.o-container--medium\@xlarge{max-width:48em}.o-container--large\@xlarge{max-width:64em}.o-container--xlarge\@xlarge{max-width:78em}.o-container--super\@xlarge{max-width:116em}}@media (min-width:116em){.o-container--xsmall\@super{max-width:20em}.o-container--small\@super{max-width:30em}.o-container--medium\@super{max-width:48em}.o-container--large\@super{max-width:64em}.o-container--xlarge\@super{max-width:78em}.o-container--super\@super{max-width:116em}}.o-container--xsmall{max-width:20em}.o-container--small{max-width:30em}.o-container--medium{max-width:48em}.o-container--large{max-width:64em}.o-container--xlarge{max-width:78em}.o-container--super{max-width:116em}