.o-timeline{margin:.55em 0 0;padding:0}.o-timeline .c-timeline-item{--timeline-item-color:var(--color-default);position:relative;padding:0 0 1.5em;list-style:none}.o-timeline .c-timeline-item:before{position:absolute;top:0;left:.25em;height:100%;margin-left:-1px;border-left:1px solid var(--color-default);content:""}.o-timeline .c-timeline-item--last:before,.o-timeline .c-timeline-item--loading:before{border-left-style:none;content:""}.o-timeline .c-timeline-item:after{position:absolute;top:0;width:.5em;height:.5em;background-color:var(--timeline-item-color);border-radius:100%;box-shadow:0 0 0 4px #fff;content:""}.o-timeline .c-timeline-item__body{position:relative;top:-.55em;margin:0 0 0 1em}.o-timeline .c-timeline-item.c-timeline-item--brand:after{--timeline-item-color:var(--color-brand);content:""}.o-timeline .c-timeline-item.c-timeline-item--info:after{--timeline-item-color:var(--color-info);content:""}.o-timeline .c-timeline-item.c-timeline-item--warning:after{--timeline-item-color:var(--color-warning);content:""}.o-timeline .c-timeline-item.c-timeline-item--success:after{--timeline-item-color:var(--color-success);content:""}.o-timeline .c-timeline-item.c-timeline-item--error:after{--timeline-item-color:var(--color-error);content:""}.o-timeline.o-timeline--alternate .c-timeline-item:after,.o-timeline.o-timeline--alternate .c-timeline-item:before{left:50%;content:""}.o-timeline.o-timeline--alternate .c-timeline-item:after{margin:0 0 0 -.25em}.o-timeline.o-timeline--alternate .c-timeline-item__body{left:50%;width:50%}.o-timeline.o-timeline--alternate .c-timeline-item--left .c-timeline-item__body{left:0;margin:0 0 0 -1em;text-align:right}.o-timeline.o-timeline--loading .c-timeline-item--last:before{border-left-style:dashed;content:""}.o-timeline.o-timeline--loading .c-timeline-item--loading:after{background-color:transparent;border:2px solid var(--color-default)}.o-timeline.o-timeline--loading .c-timeline-item--loading .c-timeline-item__body{color:var(--color-text)}