.c-button{--button-color:#fff;--button-background-color:var(--color-default);color:var(--button-color);background-color:var(--button-background-color);border:1px solid transparent;display:inline-block;max-width:100%;margin:0;padding:var(--spacing-small);overflow:hidden;font-size:1em;font-family:inherit;line-height:normal;white-space:nowrap;text-align:center;text-decoration:none;text-overflow:ellipsis;vertical-align:middle;border-radius:var(--border-radius);outline:0;-webkit-appearance:none;appearance:none;user-select:none}.c-button.c-button--active,.c-button:not(:disabled):not([disabled]):not(:active):hover{filter:brightness(.95)}.c-button:not(:disabled):not([disabled]):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-button:not(:disabled):not([disabled]):active{filter:brightness(.9)}.c-button:disabled,.c-button[disabled]{cursor:not-allowed;opacity:var(--disabled-opacity)}.c-button.c-button--close{--button-color:inherit;--button-background-color:transparent;color:var(--button-color);background-color:var(--button-background-color);border:1px solid transparent;position:absolute;right:var(--spacing-small);padding:0;font-weight:var(--text-font-weight-heavy);font-size:1.4em;line-height:1;outline:0}.c-button.c-button--close.c-button--active,.c-button.c-button--close:not(:disabled):not([disabled]):not(:active):hover{filter:brightness(.95)}.c-button.c-button--close:not(:disabled):not([disabled]):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-button.c-button--close:not(:disabled):not([disabled]):active{filter:brightness(.9)}.c-button.c-button--block{display:inline-block;width:100%}.c-button.c-button--rounded{border-radius:var(--border-radius-rounded)}.c-button.c-button--brand{--button-background-color:var(--color-brand)}.c-button.c-button--info{--button-background-color:var(--color-info)}.c-button.c-button--warning{--button-color:#000;--button-background-color:var(--color-warning)}.c-button.c-button--success{--button-background-color:var(--color-success)}.c-button.c-button--error{--button-background-color:var(--color-error)}.c-button.c-button--ghost{--button-color:var(--color-default);--button-background-color:transparent;border:1px solid var(--button-color)}.c-button.c-button--ghost.c-button--active,.c-button.c-button--ghost:not(:disabled):not([disabled]):not(:active):hover{color:#fff;background-color:var(--button-color);border-color:1px solid transparent}.c-button.c-button--ghost:not(:disabled):not([disabled]):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-button.c-button--ghost:not(:disabled):not([disabled]):active,.c-button.c-button--ghost:not(:disabled):not([disabled])[aria-current]{color:#fff;background-color:var(--button-color);border-color:1px solid transparent}.c-button.c-button--ghost.c-button--brand{--button-color:var(--color-brand)}.c-button.c-button--ghost.c-button--info{--button-color:var(--color-info)}.c-button.c-button--ghost.c-button--warning{--button-color:var(--color-warning)}.c-button.c-button--ghost.c-button--success{--button-color:var(--color-success)}.c-button.c-button--ghost.c-button--error{--button-color:var(--color-error)}.c-button.c-button--nude{width:auto;margin:0;padding:0;overflow:visible;color:inherit;font:inherit;line-height:normal;text-align:inherit;text-decoration:inherit;vertical-align:inherit;background:inherit;border:0;border-radius:0;outline:0;-webkit-appearance:none;appearance:none}.c-button.c-button--nude:disabled,.c-button.c-button--nude[disabled]{cursor:not-allowed;opacity:var(--disabled-opacity)}.c-button.c-button--nude:not(:disabled):not([disabled]):active{background-color:transparent}.c-button.c-button--nude:not(:disabled):not([disabled]):not(:active):focus{border-color:var(--border-color-focus);box-shadow:var(--box-shadow-focus)}.c-button.c-button--nude:not(:disabled):not([disabled]):not(:active):hover{background-color:transparent}.c-button__icon-left{padding-right:var(--spacing-small)}.c-button__icon-right{padding-left:var(--spacing-small)}