.o-fieldset,.o-fieldset.c-list{display:block;width:100%;margin:var(--spacing-small) 0;padding:0;border:0}.o-fieldset__legend{display:block;width:100%;padding:var(--spacing-xsmall) 0}.o-form-element{position:relative;padding:var(--spacing-medium) 0}.o-form-element .c-label:first-child{padding:0 0 var(--spacing-small) 0}