.c-github-button{display:inline-block;overflow:hidden;font-size:0;font-family:var(--text-font-family-sans-serif);white-space:nowrap;user-select:none}.c-github-button__link{display:inline-block;height:18px;padding:0 5px;color:#24292e;font-weight:600;line-height:18px;text-decoration:none;vertical-align:bottom;border:1px solid #d1d2d3;border-radius:.25em;outline:0;cursor:pointer}.c-github-button__link:focus{border-color:#c8e1ff}.c-github-button__link--button{font-size:11px;background-color:#eff3f6;background-image:linear-gradient(180deg,#fafbfc,#e4ebf0);background-repeat:repeat-x;background-size:110% 110%}.c-github-button__link--button:active{background-color:#e9ecef;background-image:none;border-color:#afb1b2;box-shadow:inset 0 .15em .3em rgba(27,31,35,.15)}.c-github-button__link--button:hover{background-color:#e6ebf1;background-image:linear-gradient(180deg,#f0f3f6,#dce3ec);border-color:#afb1b2}.c-github-button__link--count{position:relative;margin-left:5px;font-size:10px;background-color:#fff}.c-github-button__link--count:hover{color:#0366d6}.c-github-button__link--count b,.c-github-button__link--count i{position:absolute;top:50%;left:0;display:block;width:0;height:0;margin:-4px 0 0 -4px;border:4px solid transparent;border-left-width:0}.c-github-button__link--count b{border-right-color:#d1d2d3}.c-github-button__link--count:focus b{border-right-color:#c8e1ff}.c-github-button__link--count i{margin-left:-3px;border-right-color:#fff}.c-github-button__icon{position:relative;top:2px;display:inline-block;height:14px;vertical-align:top;fill:currentColor}.u-large .c-github-button__link{height:26px;line-height:26px}.u-large .c-github-button__link--button{padding:0 10px;font-size:12px}.u-large .c-github-button__link--count{margin-left:7px;padding:0 7px;font-size:11px}.u-large .c-github-button__link--count b,.u-large .c-github-button__link--count i{margin:-5px 0 0 -5px;border-width:5px 5px 5px 0}.u-large .c-github-button__link--count i{margin-left:-4px}.u-large .c-github-button__icon{top:4px;height:18px}.c-github-button__label{text-transform:capitalize}