.c-avatar{--avatar-color:#fff;--avatar-background-color:var(--color-brand);--avatar-border-radius:var(--border-radius-rounded);position:relative;display:inline-block;width:3em;height:3em;margin:0;color:var(--avatar-color);background-color:var(--avatar-background-color);border-radius:var(--avatar-border-radius)}.c-avatar[data-text]:after{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);content:attr(data-text)}.c-avatar__img[alt]{display:block;width:100%;height:100%;overflow:hidden;border-radius:var(--avatar-border-radius)}.c-avatar__img[alt]+.c-avatar__img[alt]{position:absolute;right:0;bottom:0;width:50%;height:50%}