.c-divider{display:flex;align-items:center;height:2em;font-weight:var(--text-font-weight-heavy);border:0}.c-divider:after,.c-divider:before{flex:1;padding-right:var(--grid-gutter);padding-left:var(--grid-gutter);flex:auto;border-top:1px solid var(--color-default);content:""}.c-divider.c-divider--dashed:after,.c-divider.c-divider--dashed:before{margin-right:1px;border-top-style:dashed}.c-divider.c-divider--dotted:after,.c-divider.c-divider--dotted:before{margin-right:1px;border-top-style:dotted}.c-divider__content{padding-right:var(--grid-gutter);padding-left:var(--grid-gutter);text-align:center}