.c-badge{--badge-color:#fff;--badge-background-color:var(--color-default);display:inline-block;margin:0;padding:var(--spacing-xsmall) var(--spacing-small);color:var(--badge-color);font-weight:var(--text-font-weight-heavy);font-size:.8em;line-height:1.2;background-color:var(--badge-background-color);border:var(--border-width) var(--border-style) transparent;border-radius:var(--border-radius)}.c-badge.c-badge--ghost{--badge-background-color:var(--color-transparent);--badge-color:var(--color-default);border-color:var(--badge-color)}.c-badge--rounded{border-radius:var(--border-radius-rounded)}.c-badge--brand{--badge-background-color:var(--color-brand)}.c-badge--brand.c-badge--ghost{--badge-background-color:var(--color-transparent);--badge-color:var(--color-brand)}.c-badge--info{--badge-background-color:var(--color-info)}.c-badge--info.c-badge--ghost{--badge-background-color:var(--color-transparent);--badge-color:var(--color-info)}.c-badge--warning{--badge-background-color:var(--color-warning);--badge-color:#000}.c-badge--warning.c-badge--ghost{--badge-background-color:var(--color-transparent);--badge-color:var(--color-warning)}.c-badge--success{--badge-background-color:var(--color-success)}.c-badge--success.c-badge--ghost{--badge-background-color:var(--color-transparent);--badge-color:var(--color-success)}.c-badge--error{--badge-background-color:var(--color-error)}.c-badge--error.c-badge--ghost{--badge-background-color:var(--color-transparent);--badge-color:var(--color-error)}