.c-alerts[role=presentation]{--alerts-background-color:var(--color-transparent);z-index:var(--z-over-page);display:block;max-height:100%;margin:0;padding:0;overflow-y:auto;list-style:none;background-color:var(--alerts-background-color);-webkit-overflow-scrolling:touch}.c-alerts--bottomleft,.c-alerts--bottomright,.c-alerts--topleft,.c-alerts--topright{position:fixed;width:250px}.c-alerts--topleft{top:var(--spacing-medium);left:var(--spacing-medium)}.c-alerts--topright{top:var(--spacing-medium);right:var(--spacing-medium)}.c-alerts--bottomleft{bottom:0;left:var(--spacing-medium)}.c-alerts--bottomright{right:var(--spacing-medium);bottom:0}.c-alert[role=alert]{--alert-color:#fff;--alert-background-color:var(--color-default);position:relative;margin:var(--spacing-medium);padding:var(--spacing-medium) var(--spacing-super) var(--spacing-medium) var(--spacing-medium);color:var(--alert-color);background-color:var(--alert-background-color);border-radius:var(--border-radius)}.c-alert[role=alert] .c-link{color:var(--alert-color)!important}.c-alert[role=alert].c-alert--brand{--alert-background-color:var(--color-brand)}.c-alert[role=alert].c-alert--info{--alert-background-color:var(--color-info)}.c-alert[role=alert].c-alert--warning{--alert-color:#000;--alert-background-color:var(--color-warning)}.c-alert[role=alert].c-alert--success{--alert-background-color:var(--color-success)}.c-alert[role=alert].c-alert--error{--alert-background-color:var(--color-error)}